var bulkMap = (function bulkMap$(arr, fn) {
  /* bulk-map include/functional.sibilant:1:0 */

  var index = 0,
      groupSize = fn.length,
      retArr = [];
  (function() {
    var while$6 = undefined;
    while (index < arr.length) {
      while$6 = (function() {
        retArr.push(fn.apply(this, arr.slice(index, (index + groupSize))));
        return index += groupSize;
      }).call(this);
    };
    return while$6;
  }).call(this);
  return retArr;
});
var inject = (function inject$(start, items, fn) {
  /* inject include/functional.sibilant:13:0 */

  var value = start;
  (function() {
    if (((items) && typeof (items) === "object" && (items).constructor.name === "Array")) {
      return items.forEach((function(item, index) {
        /* include/functional.sibilant:16:4 */
      
        return value = fn(value, item, index);
      }));
    }
  }).call(this);
  return value;
});
var map = (function map$(items, fn) {
  /* map include/functional.sibilant:20:0 */

  return inject([], items, (function(collector, item, index) {
    /* include/functional.sibilant:22:10 */
  
    collector.push(fn(item, index));
    return collector;
  }));
});
var select = (function select$(items, fn) {
  /* select include/functional.sibilant:26:0 */

  return inject([], items, (function(collector, item, index) {
    /* include/functional.sibilant:28:10 */
  
    (function() {
      if (fn(item, index)) {
        return collector.push(item);
      }
    }).call(this);
    return collector;
  }));
});
var detect = (function detect$(items, fn) {
  /* detect include/functional.sibilant:33:0 */

  var returnItem = undefined,
      index = 0,
      items = (items || []);
  (function() {
    var while$7 = undefined;
    while (!((items.length === index || returnItem))) {
      while$7 = (function() {
        (function() {
          if (fn(items[index], index)) {
            return returnItem = items[index];
          }
        }).call(this);
        return ((index)++);
      }).call(this);
    };
    return while$7;
  }).call(this);
  return returnItem;
});
var all__QUERY = (function all__QUERY$(items, fn) {
  /* all? include/functional.sibilant:45:0 */

  return typeof detect(items, (function(item, index) {
    /* include/functional.sibilant:46:31 */
  
    return !(fn(item, index));
  })) === "undefined";
});
var none__QUERY = (function none__QUERY$(items, fn) {
  /* none? include/functional.sibilant:48:0 */

  return typeof detect(items, fn) === "undefined";
});
var any__QUERY = (function any__QUERY$(items, fn) {
  /* any? include/functional.sibilant:51:0 */

  return typeof detect(items, fn) !== "undefined";
});
var reject = (function reject$(items, fn) {
  /* reject include/functional.sibilant:54:0 */

  var args = [ items, fn ];
  return select(items, (function() {
    /* include/functional.sibilant:56:16 */
  
    return !(fn.apply(this, arguments));
  }));
});
var compact = (function compact$(arr) {
  /* compact include/functional.sibilant:59:0 */

  return select(arr, (function(item) {
    /* include/functional.sibilant:60:17 */
  
    return (null !== item && false !== item && typeof item !== "undefined");
  }));
});
var unique = (function unique$(arr) {
  /* unique include/functional.sibilant:66:0 */

  return inject([], arr, (function(coll, item) {
    /* include/functional.sibilant:68:13 */
  
    return (function() {
      if (coll.indexOf(item) !== -1) {
        return coll;
      } else {
        return coll.concat([ item ]);
      }
    }).call(this);
  }));
});
var interleave = (function interleave$(glue, arr) {
  /* interleave include/functional.sibilant:74:0 */

  (function() {
    if ((typeof arr === "string" && ((glue) && typeof (glue) === "object" && (glue).constructor.name === "Array"))) {
      var temp = glue;
      glue = arr;
      return arr = temp;
    }
  }).call(this);
  return (function() {
    if (((glue) && typeof (glue) === "object" && (glue).constructor.name === "Array")) {
      return inject([], arr, (function(collector, item, index) {
        /* include/functional.sibilant:80:13 */
      
        return collector.concat([ item, glue[index] ]);
      }));
    } else {
      return inject([ arr[0] ], arr.slice(1), (function(collector, item, index) {
        /* include/functional.sibilant:84:13 */
      
        return collector.concat([ glue, item ]);
      }));
    }
  }).call(this);
});
var flatten = (function flatten$(items) {
  /* flatten include/functional.sibilant:87:0 */

  var items = Array.prototype.slice.call(arguments, 0);

  return inject([], items, (function(collector, item) {
    /* include/functional.sibilant:89:10 */
  
    return collector.concat((function() {
      if (((item) && typeof (item) === "object" && (item).constructor.name === "Array")) {
        return flatten.apply(this, item);
      } else {
        return item;
      }
    }).call(this));
  }));
});
var recurseMap = (function recurseMap$(item, fn) {
  /* recurse-map include/functional.sibilant:96:0 */

  return (function() {
    if (((item) && typeof (item) === "object" && (item).constructor.name === "Array")) {
      return map(item, (function(subitem) {
        /* include/functional.sibilant:97:32 */
      
        return recurseMap(subitem, fn);
      }));
    } else {
      return fn(item);
    }
  }).call(this);
});
var pluck = (function pluck$(items, attribute) {
  /* pluck include/functional.sibilant:100:0 */

  return map(items, (function(item) {
    /* include/functional.sibilant:101:16 */
  
    return item[attribute];
  }));
});
var mergeInto = (function mergeInto$(into, from) {
  /* merge-into include/functional.sibilant:103:0 */

  Object.keys(from).forEach((function(key) {
    /* include/functional.sibilant:104:5 */
  
    return into[key] = from[key];
  }));
  return into;
});
var clone = (function clone$(object) {
  /* clone include/functional.sibilant:107:0 */

  return inject({  }, Object.keys(object), (function(collector, key) {
    /* include/functional.sibilant:109:13 */
  
    collector[key] = object[key];
    return collector;
  }));
});
var values = (function values$(object) {
  /* values include/functional.sibilant:113:0 */

  return map(Object.keys(object), (function() {
    /* include/functional.sibilant:114:26 */
  
    return object[arguments[0]];
  }));
});
var mapValues = (function mapValues$(object, fn) {
  /* map-values include/functional.sibilant:116:0 */

  return inject({  }, Object.keys(object), (function(collector, key, index) {
    /* include/functional.sibilant:118:13 */
  
    collector[key] = fn(object[key], key);
    return collector;
  }));
});
var mergeWith = (function mergeWith$(into, from) {
  /* merge-with include/functional.sibilant:122:0 */

  return mergeInto(clone(into), from);
});
var extractOptions = (function extractOptions$(config, args) {
  /* extract-options src/options.sibilant:3:0 */

  args = (typeof args !== "undefined") ? args : process.argv.slice(2);
  var defaultLabel = "unlabeled",
      currentLabel = defaultLabel,
      afterBreak = false,
      config = (config || {  }),
      unlabeled = [];
  var label__QUERY = (function label__QUERY$(item) {
    /* label? src/options.sibilant:11:5 */
  
    return (typeof item === "string" && /^-/.test(item));
  });
  var synonymLookup = (function synonymLookup$(item) {
    /* synonym-lookup src/options.sibilant:13:5 */
  
    var configEntry = config[item];
    return (function() {
      if (typeof configEntry === "string") {
        return synonymLookup(configEntry);
      } else {
        return item;
      }
    }).call(this);
  });
  var takesArgs__QUERY = (function takesArgs__QUERY$(item) {
    /* takes-args? src/options.sibilant:19:5 */
  
    return false !== config[labelFor(item)];
  });
  defaultLabel = synonymLookup(defaultLabel);
  currentLabel = defaultLabel;
  var labelFor = (function labelFor$(item) {
    /* label-for src/options.sibilant:25:5 */
  
    return synonymLookup(item.replace(/^-+/, ""));
  });
  var addValue = (function addValue$(hash, key, value) {
    /* add-value src/options.sibilant:28:5 */
  
    var currentValue = hash[key];
    (function() {
      if (typeof currentValue === "undefined") {
        currentValue = [];
        return hash[key] = currentValue;
      }
    }).call(this);
    return (function() {
      if (true !== value) {
        return currentValue.push(value);
      }
    }).call(this);
  });
  var resetLabel = (function resetLabel$() {
    /* reset-label src/options.sibilant:36:5 */
  
    return currentLabel = defaultLabel;
  });
  return inject({  }, args, (function(returnHash, item, index) {
    /* src/options.sibilant:40:13 */
  
    (function() {
      if ("--" === item) {
        return afterBreak = true;
      } else {
        return (function() {
          if (afterBreak) {
            return addValue(returnHash, "afterBreak", item);
          } else {
            return (function() {
              if (label__QUERY(item)) {
                currentLabel = labelFor(item);
                addValue(returnHash, currentLabel, true);
                return (function() {
                  if (!(takesArgs__QUERY(item))) {
                    return resetLabel();
                  }
                }).call(this);
              } else {
                addValue(returnHash, currentLabel, item);
                return resetLabel();
              }
            }).call(this);
          }
        }).call(this);
      }
    }).call(this);
    return returnHash;
  }));
});
var processOptions = (function processOptions$(config) {
  /* process-options src/options.sibilant:54:0 */

  var options = extractOptions(config);
  (function() {
    if (config) {
      var handlePair = (function handlePair$(key, value) {
        /* handle-pair src/options.sibilant:57:11 */
      
        var handle = config[key];
        (function() {
          if (typeof handle === "string") {
            return handlePair(handle, value);
          }
        }).call(this);
        return (function() {
          if (typeof handle === "function") {
            return handle(value, options);
          }
        }).call(this);
      });
      return Object.keys(options).forEach((function(key) {
        /* src/options.sibilant:61:11 */
      
        return handlePair(key, options[key]);
      }));
    }
  }).call(this);
  return options;
});
module.exports = processOptions;